%% Model of seismic source waveform .
%% In this illustration, the waveform is obtained by summation of multiple cosine functions
%% This summation is called the Fourier transform.
%% Although this transform can be performed by simply calling "fft" 
%% (Fast fourier transform, or FFT), we perform it here in the "slow" way - 
%% by direct summation of cosine harmonics.
%% In this way, we will see how the FFT works.

%% Parameters:
%%  t - array of times in milliseconds at which the values of the waveform are output 
%%      (these times should normally contain time t0)
%%  domfreq - "dominant" frequency of the wavelet to generate, in Hz

%% Return values:
%%  wave - array of wavelet values at times given in 't'

function [wave] = wavelet_ft(t,domfreq)
  
  if nargin < 1   % frequency not given - use 30 Hz
      domfreq = 30.0;
  end
  
  freq = (0.5:0.002:2)*0.001*domfreq;   % frequencies of cosine functions from 20 to 60 Hz
         
    % initialize the output array with zeros 
         
  wave = zeros(1,length(t)); 
	 
    % sum cosine functions to obtain an impulsive shape (symmetric in time)
% #	  x - source-receiver distance (can be an scalar or array, 

  for k=1:length(freq)
    wave = wave + cos(2*pi*freq(k)*t );
  end
   
    % scale the resulting waveform so that its amplitude at t=0 equals 1.0
    
  wave = wave/length(freq);
  
    % the wavelet still looks a bit more reverberatory than we would like
    % in these labs. 
    % Therefore, multiply it by a Gaussian function to reduce side lobes.
        
  wave = wave.*exp(-(t*domfreq*0.0015).^2);
  
    % The result looks close to Ricker wavelet with small additional
    % side lobes
  
end



